#from setuptools import setup
from distutils.core import setup


setup(
    name='rimac-analytics',
    version='0.3.1',
    description='Rimac Analytics API',
    author='Diego y Ricardito',
    author_email='ddce.2005@gmail.com',
    zip_safe=False,
    url='https://bitbucket.org/rimac-analytics/rimac-analytics-api',
    license='MIT',
    packages=['utils', 'decorators', 'common'],
    python_requires='>=3'
)
